@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,19 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -34,8 +32,7 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.workflows.executions_v1beta.services.executions import pagers
 from google.cloud.workflows.executions_v1beta.types import executions
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ExecutionsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ExecutionsGrpcTransport
 from .transports.grpc_asyncio import ExecutionsGrpcAsyncIOTransport
@@ -54,7 +51,7 @@ class ExecutionsClientMeta(type):
     _transport_registry["grpc_asyncio"] = ExecutionsGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[ExecutionsTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -80,7 +77,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -114,7 +112,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -131,7 +130,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -150,10 +149,11 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @property
     def transport(self) -> ExecutionsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            ExecutionsTransport: The transport used by the client instance.
+            ExecutionsTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
@@ -161,14 +161,14 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
     def execution_path(
         project: str, location: str, workflow: str, execution: str,
     ) -> str:
-        """Return a fully-qualified execution string."""
+        """Returns a fully-qualified execution string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}".format(
             project=project, location=location, workflow=workflow, execution=execution,
         )
 
     @staticmethod
     def parse_execution_path(path: str) -> Dict[str, str]:
-        """Parse a execution path into its component segments."""
+        """Parses a execution path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/workflows/(?P<workflow>.+?)/executions/(?P<execution>.+?)$",
             path,
@@ -177,14 +177,14 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def workflow_path(project: str, location: str, workflow: str,) -> str:
-        """Return a fully-qualified workflow string."""
+        """Returns a fully-qualified workflow string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}".format(
             project=project, location=location, workflow=workflow,
         )
 
     @staticmethod
     def parse_workflow_path(path: str) -> Dict[str, str]:
-        """Parse a workflow path into its component segments."""
+        """Parses a workflow path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/workflows/(?P<workflow>.+?)$",
             path,
@@ -193,7 +193,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -206,7 +206,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -217,7 +217,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -228,7 +228,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -239,7 +239,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -253,12 +253,12 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ExecutionsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the executions client.
+        """Instantiates the executions client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -313,9 +313,10 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -327,12 +328,14 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -347,8 +350,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -361,11 +364,12 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def list_executions(
         self,
-        request: executions.ListExecutionsRequest = None,
+        request: Union[executions.ListExecutionsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -379,7 +383,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         first).
 
         Args:
-            request (google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest):
+            request (Union[google.cloud.workflows.executions_v1beta.types.ListExecutionsRequest, dict]):
                 The request object. Request for the
                 [ListExecutions][google.cloud.workflows.executions.v1beta.Executions.ListExecutions]
                 method.
@@ -392,7 +396,6 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -425,10 +428,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, executions.ListExecutionsRequest):
             request = executions.ListExecutionsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -456,7 +457,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     def create_execution(
         self,
-        request: executions.CreateExecutionRequest = None,
+        request: Union[executions.CreateExecutionRequest, dict] = None,
         *,
         parent: str = None,
         execution: executions.Execution = None,
@@ -468,7 +469,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         the given workflow.
 
         Args:
-            request (google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest):
+            request (Union[google.cloud.workflows.executions_v1beta.types.CreateExecutionRequest, dict]):
                 The request object. Request for the
                 [CreateExecution][google.cloud.workflows.executions.v1beta.Executions.CreateExecution]
                 method.
@@ -488,7 +489,6 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 This corresponds to the ``execution`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -517,10 +517,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, executions.CreateExecutionRequest):
             request = executions.CreateExecutionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if execution is not None:
@@ -544,7 +542,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     def get_execution(
         self,
-        request: executions.GetExecutionRequest = None,
+        request: Union[executions.GetExecutionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -554,7 +552,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         r"""Returns an execution of the given name.
 
         Args:
-            request (google.cloud.workflows.executions_v1beta.types.GetExecutionRequest):
+            request (Union[google.cloud.workflows.executions_v1beta.types.GetExecutionRequest, dict]):
                 The request object. Request for the
                 [GetExecution][google.cloud.workflows.executions.v1beta.Executions.GetExecution]
                 method.
@@ -566,7 +564,6 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -595,10 +592,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, executions.GetExecutionRequest):
             request = executions.GetExecutionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -620,7 +615,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
 
     def cancel_execution(
         self,
-        request: executions.CancelExecutionRequest = None,
+        request: Union[executions.CancelExecutionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -630,7 +625,7 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         r"""Cancels an execution of the given name.
 
         Args:
-            request (google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest):
+            request (Union[google.cloud.workflows.executions_v1beta.types.CancelExecutionRequest, dict]):
                 The request object. Request for the
                 [CancelExecution][google.cloud.workflows.executions.v1beta.Executions.CancelExecution]
                 method.
@@ -642,7 +637,6 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -671,10 +665,8 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, executions.CancelExecutionRequest):
             request = executions.CancelExecutionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -694,6 +686,19 @@ class ExecutionsClient(metaclass=ExecutionsClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
