@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -97,25 +94,17 @@ class Execution(proto.Message):
                 debugging purposes.
         """
 
-        payload = proto.Field(proto.STRING, number=1)
-
-        context = proto.Field(proto.STRING, number=2)
-
-    name = proto.Field(proto.STRING, number=1)
-
-    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp.Timestamp,)
+        payload = proto.Field(proto.STRING, number=1,)
+        context = proto.Field(proto.STRING, number=2,)
 
+    name = proto.Field(proto.STRING, number=1,)
+    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
     state = proto.Field(proto.ENUM, number=4, enum=State,)
-
-    argument = proto.Field(proto.STRING, number=5)
-
-    result = proto.Field(proto.STRING, number=6)
-
+    argument = proto.Field(proto.STRING, number=5,)
+    result = proto.Field(proto.STRING, number=6,)
     error = proto.Field(proto.MESSAGE, number=7, message=Error,)
-
-    workflow_revision_id = proto.Field(proto.STRING, number=8)
+    workflow_revision_id = proto.Field(proto.STRING, number=8,)
 
 
 class ListExecutionsRequest(proto.Message):
@@ -149,12 +138,9 @@ class ListExecutionsRequest(proto.Message):
             will default to the BASIC view.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
     view = proto.Field(proto.ENUM, number=4, enum="ExecutionView",)
 
 
@@ -177,8 +163,7 @@ class ListExecutionsResponse(proto.Message):
         return self
 
     executions = proto.RepeatedField(proto.MESSAGE, number=1, message="Execution",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateExecutionRequest(proto.Message):
@@ -197,8 +182,7 @@ class CreateExecutionRequest(proto.Message):
             Required. Execution to be created.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     execution = proto.Field(proto.MESSAGE, number=2, message="Execution",)
 
 
@@ -218,8 +202,7 @@ class GetExecutionRequest(proto.Message):
             will default to the FULL view.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
+    name = proto.Field(proto.STRING, number=1,)
     view = proto.Field(proto.ENUM, number=2, enum="ExecutionView",)
 
 
@@ -235,7 +218,7 @@ class CancelExecutionRequest(proto.Message):
             projects/{project}/locations/{location}/workflows/{workflow}/executions/{execution}
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
