@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -350,11 +350,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def list_workflows(
         self,
-        request: workflows.ListWorkflowsRequest = None,
+        request: Union[workflows.ListWorkflowsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -365,7 +366,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         The default order is not specified.
 
         Args:
-            request (google.cloud.workflows_v1.types.ListWorkflowsRequest):
+            request (Union[google.cloud.workflows_v1.types.ListWorkflowsRequest, dict]):
                 The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1.Workflows.ListWorkflows]
                 method.
@@ -439,7 +440,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def get_workflow(
         self,
-        request: workflows.GetWorkflowRequest = None,
+        request: Union[workflows.GetWorkflowRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -449,7 +450,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         r"""Gets details of a single Workflow.
 
         Args:
-            request (google.cloud.workflows_v1.types.GetWorkflowRequest):
+            request (Union[google.cloud.workflows_v1.types.GetWorkflowRequest, dict]):
                 The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1.Workflows.GetWorkflow]
                 method.
@@ -512,7 +513,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def create_workflow(
         self,
-        request: workflows.CreateWorkflowRequest = None,
+        request: Union[workflows.CreateWorkflowRequest, dict] = None,
         *,
         parent: str = None,
         workflow: workflows.Workflow = None,
@@ -527,7 +528,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
         Args:
-            request (google.cloud.workflows_v1.types.CreateWorkflowRequest):
+            request (Union[google.cloud.workflows_v1.types.CreateWorkflowRequest, dict]):
                 The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1.Workflows.CreateWorkflow]
                 method.
@@ -626,7 +627,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def delete_workflow(
         self,
-        request: workflows.DeleteWorkflowRequest = None,
+        request: Union[workflows.DeleteWorkflowRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -638,7 +639,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         executions of the workflow.
 
         Args:
-            request (google.cloud.workflows_v1.types.DeleteWorkflowRequest):
+            request (Union[google.cloud.workflows_v1.types.DeleteWorkflowRequest, dict]):
                 The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1.Workflows.DeleteWorkflow]
                 method.
@@ -722,7 +723,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def update_workflow(
         self,
-        request: workflows.UpdateWorkflowRequest = None,
+        request: Union[workflows.UpdateWorkflowRequest, dict] = None,
         *,
         workflow: workflows.Workflow = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -738,7 +739,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         used in new workflow executions.
 
         Args:
-            request (google.cloud.workflows_v1.types.UpdateWorkflowRequest):
+            request (Union[google.cloud.workflows_v1.types.UpdateWorkflowRequest, dict]):
                 The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1.Workflows.UpdateWorkflow]
                 method.
@@ -819,6 +820,19 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
