@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,20 +20,19 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.workflows_v1beta.services.workflows import pagers
 from google.cloud.workflows_v1beta.types import workflows
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WorkflowsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import WorkflowsGrpcAsyncIOTransport
 from .client import WorkflowsClient
@@ -54,25 +51,20 @@ class WorkflowsAsyncClient:
 
     workflow_path = staticmethod(WorkflowsClient.workflow_path)
     parse_workflow_path = staticmethod(WorkflowsClient.parse_workflow_path)
-
     common_billing_account_path = staticmethod(
         WorkflowsClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         WorkflowsClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(WorkflowsClient.common_folder_path)
     parse_common_folder_path = staticmethod(WorkflowsClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(WorkflowsClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         WorkflowsClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(WorkflowsClient.common_project_path)
     parse_common_project_path = staticmethod(WorkflowsClient.parse_common_project_path)
-
     common_location_path = staticmethod(WorkflowsClient.common_location_path)
     parse_common_location_path = staticmethod(
         WorkflowsClient.parse_common_location_path
@@ -80,7 +72,8 @@ class WorkflowsAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -95,7 +88,7 @@ class WorkflowsAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -112,7 +105,7 @@ class WorkflowsAsyncClient:
 
     @property
     def transport(self) -> WorkflowsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             WorkflowsTransport: The transport used by the client instance.
@@ -126,12 +119,12 @@ class WorkflowsAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, WorkflowsTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the workflows client.
+        """Instantiates the workflows client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -163,7 +156,6 @@ class WorkflowsAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = WorkflowsClient(
             credentials=credentials,
             transport=transport,
@@ -197,7 +189,6 @@ class WorkflowsAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -228,7 +219,6 @@ class WorkflowsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
 
@@ -282,7 +272,6 @@ class WorkflowsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -309,7 +298,6 @@ class WorkflowsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -383,7 +371,6 @@ class WorkflowsAsyncClient:
                 This corresponds to the ``workflow_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -413,7 +400,6 @@ class WorkflowsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if parent is not None:
             request.parent = parent
         if workflow is not None:
@@ -475,7 +461,6 @@ class WorkflowsAsyncClient:
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -515,7 +500,6 @@ class WorkflowsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if name is not None:
             request.name = name
 
@@ -540,7 +524,7 @@ class WorkflowsAsyncClient:
         response = operation_async.from_gapic(
             response,
             self._client._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=workflows.OperationMetadata,
         )
 
@@ -552,7 +536,7 @@ class WorkflowsAsyncClient:
         request: workflows.UpdateWorkflowRequest = None,
         *,
         workflow: workflows.Workflow = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -582,7 +566,6 @@ class WorkflowsAsyncClient:
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -612,7 +595,6 @@ class WorkflowsAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if workflow is not None:
             request.workflow = workflow
         if update_mask is not None:
@@ -648,6 +630,12 @@ class WorkflowsAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
