@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,19 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,10 +34,9 @@ from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.workflows_v1beta.services.workflows import pagers
 from google.cloud.workflows_v1beta.types import workflows
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import WorkflowsTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import WorkflowsGrpcTransport
 from .transports.grpc_asyncio import WorkflowsGrpcAsyncIOTransport
@@ -58,7 +55,7 @@ class WorkflowsClientMeta(type):
     _transport_registry["grpc_asyncio"] = WorkflowsGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[WorkflowsTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -84,7 +81,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -118,7 +116,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -135,7 +134,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -154,23 +153,24 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @property
     def transport(self) -> WorkflowsTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            WorkflowsTransport: The transport used by the client instance.
+            WorkflowsTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def workflow_path(project: str, location: str, workflow: str,) -> str:
-        """Return a fully-qualified workflow string."""
+        """Returns a fully-qualified workflow string."""
         return "projects/{project}/locations/{location}/workflows/{workflow}".format(
             project=project, location=location, workflow=workflow,
         )
 
     @staticmethod
     def parse_workflow_path(path: str) -> Dict[str, str]:
-        """Parse a workflow path into its component segments."""
+        """Parses a workflow path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/workflows/(?P<workflow>.+?)$",
             path,
@@ -179,7 +179,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -192,7 +192,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -203,7 +203,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -214,7 +214,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -225,7 +225,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -239,12 +239,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, WorkflowsTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the workflows client.
+        """Instantiates the workflows client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -299,9 +299,10 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -313,12 +314,14 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -333,8 +336,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -347,11 +350,12 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def list_workflows(
         self,
-        request: workflows.ListWorkflowsRequest = None,
+        request: Union[workflows.ListWorkflowsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -362,7 +366,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         The default order is not specified.
 
         Args:
-            request (google.cloud.workflows_v1beta.types.ListWorkflowsRequest):
+            request (Union[google.cloud.workflows_v1beta.types.ListWorkflowsRequest, dict]):
                 The request object. Request for the
                 [ListWorkflows][google.cloud.workflows.v1beta.Workflows.ListWorkflows]
                 method.
@@ -375,7 +379,6 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -408,10 +411,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, workflows.ListWorkflowsRequest):
             request = workflows.ListWorkflowsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -439,7 +440,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def get_workflow(
         self,
-        request: workflows.GetWorkflowRequest = None,
+        request: Union[workflows.GetWorkflowRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -449,7 +450,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         r"""Gets details of a single Workflow.
 
         Args:
-            request (google.cloud.workflows_v1beta.types.GetWorkflowRequest):
+            request (Union[google.cloud.workflows_v1beta.types.GetWorkflowRequest, dict]):
                 The request object. Request for the
                 [GetWorkflow][google.cloud.workflows.v1beta.Workflows.GetWorkflow]
                 method.
@@ -461,7 +462,6 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -490,10 +490,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, workflows.GetWorkflowRequest):
             request = workflows.GetWorkflowRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -515,7 +513,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def create_workflow(
         self,
-        request: workflows.CreateWorkflowRequest = None,
+        request: Union[workflows.CreateWorkflowRequest, dict] = None,
         *,
         parent: str = None,
         workflow: workflows.Workflow = None,
@@ -530,7 +528,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         [ALREADY_EXISTS][google.rpc.Code.ALREADY_EXISTS] error.
 
         Args:
-            request (google.cloud.workflows_v1beta.types.CreateWorkflowRequest):
+            request (Union[google.cloud.workflows_v1beta.types.CreateWorkflowRequest, dict]):
                 The request object. Request for the
                 [CreateWorkflow][google.cloud.workflows.v1beta.Workflows.CreateWorkflow]
                 method.
@@ -563,7 +561,6 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 This corresponds to the ``workflow_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -595,10 +592,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, workflows.CreateWorkflowRequest):
             request = workflows.CreateWorkflowRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if workflow is not None:
@@ -632,7 +627,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def delete_workflow(
         self,
-        request: workflows.DeleteWorkflowRequest = None,
+        request: Union[workflows.DeleteWorkflowRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -644,7 +639,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         executions of the workflow.
 
         Args:
-            request (google.cloud.workflows_v1beta.types.DeleteWorkflowRequest):
+            request (Union[google.cloud.workflows_v1beta.types.DeleteWorkflowRequest, dict]):
                 The request object. Request for the
                 [DeleteWorkflow][google.cloud.workflows.v1beta.Workflows.DeleteWorkflow]
                 method.
@@ -656,7 +651,6 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -698,10 +692,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, workflows.DeleteWorkflowRequest):
             request = workflows.DeleteWorkflowRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -722,7 +714,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=workflows.OperationMetadata,
         )
 
@@ -731,10 +723,10 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
 
     def update_workflow(
         self,
-        request: workflows.UpdateWorkflowRequest = None,
+        request: Union[workflows.UpdateWorkflowRequest, dict] = None,
         *,
         workflow: workflows.Workflow = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -747,7 +739,7 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         used in new workflow executions.
 
         Args:
-            request (google.cloud.workflows_v1beta.types.UpdateWorkflowRequest):
+            request (Union[google.cloud.workflows_v1beta.types.UpdateWorkflowRequest, dict]):
                 The request object. Request for the
                 [UpdateWorkflow][google.cloud.workflows.v1beta.Workflows.UpdateWorkflow]
                 method.
@@ -764,7 +756,6 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -796,10 +787,8 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # there are no flattened fields.
         if not isinstance(request, workflows.UpdateWorkflowRequest):
             request = workflows.UpdateWorkflowRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if workflow is not None:
                 request.workflow = workflow
             if update_mask is not None:
@@ -831,6 +820,19 @@ class WorkflowsClient(metaclass=WorkflowsClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
